.. _image:

**************************
image
**************************

This module provides access to various image manipulation functions.

.. currentmodule:: stsci.image._image

.. automodule:: stsci.image._image
   :members:
   :undoc-members:
   

.. currentmodule:: stsci.image.combine

.. automodule:: stsci.image.combine
   :members:
   :undoc-members:
